"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = shallowReflectiveEqual;

var _reflectiveBind = require("./reflectiveBind");

function _typeof(obj) { if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

// Originally copied from
// https://github.com/facebook/fbjs/blob/v0.8.16/src/core/shallowEqual.js
var hasOwnProperty = Object.prototype.hasOwnProperty;
/**
 * inlined Object.is polyfill to avoid requiring consumers ship their own
 * https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Object/is
 */

function is(x
/*: mixed*/
, y
/*: mixed*/
)
/*: boolean*/
{
  // SameValue algorithm
  if (x === y) {
    // Steps 1-5, 7-10
    // Steps 6.b-6.e: +0 != -0
    // Added the nonzero y check to make Flow happy, but it is redundant
    return x !== 0 || y !== 0 || 1 / x === 1 / y;
  } else {
    // Step 6.a: NaN == NaN
    return x !== x && y !== y;
  }
}
/**
 * Performs equality by iterating through keys on an object and returning false
 * when any key has values which are not strictly or reflectively equal between
 * the arguments. Returns true otherwise.
 */


function shallowReflectiveEqual(objA
/*: mixed*/
, objB
/*: mixed*/
)
/*: boolean*/
{
  if (is(objA, objB)) {
    return true;
  }

  if (_typeof(objA) !== "object" || objA === null || _typeof(objB) !== "object" || objB === null) {
    return false;
  }

  var keysA = Object.keys(objA);
  var keysB = Object.keys(objB);

  if (keysA.length !== keysB.length) {
    return false;
  } // Test for A's keys different from B.


  for (var i = 0; i < keysA.length; i++) {
    if (!hasOwnProperty.call(objB, keysA[i]) || !is(objA[keysA[i]], objB[keysA[i]]) && !(0, _reflectiveBind.reflectiveEqual)(objA[keysA[i]], objB[keysA[i]])) {
      return false;
    }
  }

  return true;
}